@@ -43,7 +43,7 @@ namespace Tomboy
 			}
 #endif // ENABLE_DBUS || WIN32
 
-			Initialize ("tomboy", "Tomboy", "tomboy", args);
+			Initialize ("tomboy", "tomboy", "tomboy", args);
 
 			// Add private icon dir to search path
 			icon_theme = Gtk.IconTheme.Default;
@@ -84,6 +84,8 @@ namespace Tomboy
 				am ["QuitTomboyAction"].Visible = false;
 
 				RegisterPanelAppletFactory ();
+				Logger.Log ("All done.  Ciao!");
+				Exit (0);
 			} else {
 				RegisterSessionManagerRestart (
 				        Environment.GetEnvironmentVariable ("TOMBOY_WRAPPER_PATH"),
@@ -300,7 +302,11 @@ namespace Tomboy
 			about.Comments = Catalog.GetString ("A simple and easy to use desktop " +
 			                                    "note-taking application.");
 			Gtk.AboutDialog.SetUrlHook (delegate (Gtk.AboutDialog dialog, string link) {
-				Services.NativeApplication.OpenUrl (link);
+				try {
+					Services.NativeApplication.OpenUrl (link);
+				} catch (Exception e) {
+					GuiUtils.ShowOpeningLocationError (dialog, link, e.Message);
+				}
 			}); 
 			about.Website = Defines.TOMBOY_WEBSITE;
 			about.WebsiteLabel = Catalog.GetString("Homepage");
